pub struct OnlineStats { /* private fields */ }Expand description
Online mean/variance accumulator for building EntityBaseline values.
Uses Welford’s algorithm, so callers can update an environmental baseline one observation at a time without storing raw samples.
Implementations
Sourceimpl OnlineStats
impl OnlineStats
pub fn new() -> Self
pub fn push(&mut self, value: f64)
pub fn count(&self) -> u64
pub fn is_empty(&self) -> bool
pub fn mean(&self) -> f64
pub fn std_dev(&self) -> f64
pub fn to_baseline( &self, entity: impl Into<String>, metric: impl Into<String>, ) -> EntityBaseline