pub struct BehaviorRegistry { /* private fields */ }Expand description
Versioned, append-only registry of behaviour patterns. Cheap to clone
(Arc-wrapped). register keeps the highest-version pattern per id.
Implementations
Sourceimpl BehaviorRegistry
impl BehaviorRegistry
Sourcepub fn register(&self, pattern: BehaviorPattern)
pub fn register(&self, pattern: BehaviorPattern)
Register a pattern, replacing an existing pattern with the same id when the new version is greater than or equal to the stored version.
Sourcepub fn extend<I: IntoIterator<Item = BehaviorPattern>>(&self, patterns: I)
pub fn extend<I: IntoIterator<Item = BehaviorPattern>>(&self, patterns: I)
Register every pattern from patterns.
Sourcepub fn snapshot(&self) -> Vec<BehaviorPattern>
pub fn snapshot(&self) -> Vec<BehaviorPattern>
Clone all registered patterns in registry order.