Module projection

Module projection 

Projection helpers for rig-compose context packing.

Traits

IntoContextItem
Convert resource-native records into ContextItem values.

Functions

evidence_to_context_item
Project one evidence record into a context item.
evidence_to_context_items
Project all accumulated investigation evidence into resource or memory context items.
memory_hit_to_context_item
Project a memory lookup hit into a ranked memory context item.
memory_hits_to_context_items
Project memory lookup hits into ranked memory context items.
pack_resource_context
Pack resource-projected context items with the shared kernel packer.